# charinfo

 A command line tool to view detailed information about a character

## Screenshots

Hover over them to know their description

![Directly passing the character](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_direct.png "Directly passing the character")
![Directly passing multiple characters](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_multiple.png "Directly passing multiple characters")
![Passing the name of the character](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_name.png "Passing the name of the character")
![Passing the name of multiple characters](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_name_multiple.png "Passing the name of multiple characters")
![Passing the unicode codepoint of the character](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_unicode.png "Passing the unicode codepoint of the character")
![Passing the decimal representation of the unicode codepoint of the character](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_decimal.png "Passing the decimal representation of the unicode codepoint of the character")
